==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d0/dd0/gfx__func_8h.js <==
var gfx__func_8h =
[
    [ "FONT_HEIGHT_LARGE", "d0/dd0/gfx__func_8h.html#a62522eeeaeb5b50af998dd8a13c447ad", null ],
    [ "FONT_HEIGHT_MONO", "d0/dd0/gfx__func_8h.html#a20b4e79411746dbd31e86ebbfd85e165", null ],
    [ "FONT_HEIGHT_NORMAL", "d0/dd0/gfx__func_8h.html#aff2dc4db5e63c9597125d923bedf2d6d", null ],
    [ "FONT_HEIGHT_SMALL", "d0/dd0/gfx__func_8h.html#a5c56df453a90cf0ee7b3aea41066df3d", null ],
    [ "GREY_SCALE", "d0/dd0/gfx__func_8h.html#afaa28737e6c4dd61079432236d6adaac", null ],
    [ "StringAlignment", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99", [
      [ "SA_LEFT", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a3299fdf5121ed16058ef242d7099f3cc", null ],
      [ "SA_HOR_CENTER", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a48262457106fe5a646c69912d722b465", null ],
      [ "SA_RIGHT", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a420b1bf5f176ea6c3ba6e6e21b334952", null ],
      [ "SA_HOR_MASK", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a38d19f9fd4e7355cc792ac751b2d056e", null ],
      [ "SA_TOP", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a2f65bd3a8e603db1d1ae97860e33919a", null ],
      [ "SA_VERT_CENTER", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99ac2ee4321f6ad27b143c45c3e08968102", null ],
      [ "SA_BOTTOM", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a6aa2b6fbb48e4473e800e7335527690f", null ],
      [ "SA_VERT_MASK", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a5bc08c8f21ed0859789898bdd626f774", null ],
      [ "SA_CENTER", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a860dce55fa7e76a776416e5b76fb2da2", null ],
      [ "SA_FORCE", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a5f69c54d9f8d7622a343b4613a90497c", null ]
    ] ],
    [ "CenterBounds", "d0/dd0/gfx__func_8h.html#a4b9b860f8f2f8bb3e04243eedc07aa74", null ],
    [ "ChangeResInGame", "d0/dd0/gfx__func_8h.html#ad1eb7560f1d63180c05e3e3bf9e2c9d7", null ],
    [ "CheckBlitter", "d0/dd0/gfx__func_8h.html#a765d119fce0424280141f196d128a1be", null ],
    [ "CreateConsole", "d0/dd0/gfx__func_8h.html#a9c93eb8d3d9e95f670a42345713af01a", null ],
    [ "CSleep", "d0/dd0/gfx__func_8h.html#a04192f4474b4eb1abf1a7a2e96167209", null ],
    [ "CursorTick", "d0/dd0/gfx__func_8h.html#a21b47af832d17183a571d33709eb4ca4", null ],
    [ "DrawBox", "d0/dd0/gfx__func_8h.html#adcea9bd22fff70a074b68f66ef028aff", null ],
    [ "DrawCharCentered", "d0/dd0/gfx__func_8h.html#aa54306a0cf2fb5e3c7630f0dbbd0350e", null ],
    [ "DrawDirtyBlocks", "d0/dd0/gfx__func_8h.html#a82dbdab183007a06f3319f7e7e44d132", null ],
    [ "DrawMouseCursor", "d0/dd0/gfx__func_8h.html#a7474f42828d5ea48e4a7793cc1d63823", null ],
    [ "DrawOverlappedWindowForAll", "d0/dd0/gfx__func_8h.html#a3017c7de18d32f3149e840c144b6aeef", null ],
    [ "DrawSprite", "d0/dd0/gfx__func_8h.html#ac604c0efd7e075224d2c5fc96d28cb36", null ],
    [ "DrawSpriteViewport", "d0/dd0/gfx__func_8h.html#a967cd03b8c2c61c6f1e733d44b0101ec", null ],
    [ "DrawString", "d0/dd0/gfx__func_8h.html#ac190834d6a4461d59a9d215015a5aa18", null ],
    [ "DrawString", "d0/dd0/gfx__func_8h.html#ab9c4cb4c78da47ab7772ace22be8a528", null ],
    [ "DrawStringMultiLine", "d0/dd0/gfx__func_8h.html#a91ad98f20f66633184f425ac064eba90", null ],
    [ "DrawStringMultiLine", "d0/dd0/gfx__func_8h.html#ac051d286b4e5c9ee3b60daeb8d583394", null ],
    [ "FillDrawPixelInfo", "d0/dd0/gfx__func_8h.html#aea9706a3f0deee7c415df4bcd4bbd243", null ],
    [ "GameLoop", "d0/dd0/gfx__func_8h.html#a1ccba604c34743e18775c4c72ff36948", null ],
    [ "GameSizeChanged", "d0/dd0/gfx__func_8h.html#a4560d58565a10931cc872203e4507e0c", null ],
    [ "GetBroadestDigit", "d0/dd0/gfx__func_8h.html#a7f2db578b3c0d8c001492d28e004ab99", null ],
    [ "GetCharacterHeight", "d0/dd0/gfx__func_8h.html#abdc18f304b99c345a3fb9774371ec96b", null ],
    [ "GetCharacterWidth", "d0/dd0/gfx__func_8h.html#a5da0e79597b6941c73ebe1bed627b93d", null ],
    [ "GetCharAtPosition", "d0/dd0/gfx__func_8h.html#a89ae5a88a0c9bf3a615a74aada8aa0ec", null ],
    [ "GetCharPosInString", "d0/dd0/gfx__func_8h.html#a3b0d4ca81479d54226a5c8c3760ba915", null ],
    [ "GetContrastColour", "d0/dd0/gfx__func_8h.html#a94bbc005155c19357e771c20b30303f6", null ],
    [ "GetDigitWidth", "d0/dd0/gfx__func_8h.html#abe6fcc04b86b6238f1f10250d863d92c", null ],
    [ "GetSpriteSize", "d0/dd0/gfx__func_8h.html#a7161fa05591855d1c6be5454dfcc1d42", null ],
    [ "GetStringBoundingBox", "d0/dd0/gfx__func_8h.html#a4115002109446ab9b55f902dce0e50ff", null ],
    [ "GetStringBoundingBox", "d0/dd0/gfx__func_8h.html#a7bc77418c11174e17dceaa9c279d3423", null ],
    [ "GetStringHeight", "d0/dd0/gfx__func_8h.html#ae818cb9dcd589e3430675b5a64ae035f", null ],
    [ "GetStringHeight", "d0/dd0/gfx__func_8h.html#ac7aaeb816ab4f8f3cdf11e55d7603cc2", null ],
    [ "GetStringLineCount", "d0/dd0/gfx__func_8h.html#a39ed16837962bcfdef87e98f97df84b9", null ],
    [ "GetStringMultiLineBoundingBox", "d0/dd0/gfx__func_8h.html#ab8a303b48a03621231a4682580bbf6f8", null ],
    [ "GetStringMultiLineBoundingBox", "d0/dd0/gfx__func_8h.html#a07bf77588ca7fafb6339af33098483d0", null ],
    [ "GfxDrawLine", "d0/dd0/gfx__func_8h.html#a52fc1ddbafcb899fdabae7563daa95f6", null ],
    [ "GfxFillRect", "d0/dd0/gfx__func_8h.html#ad176599a86e2c97daec082e2566223c2", null ],
    [ "GfxInitPalettes", "d0/dd0/gfx__func_8h.html#a447580145f88c4c8a962cc7299eb542d", null ],
    [ "GfxScroll", "d0/dd0/gfx__func_8h.html#a580ce1d1be3c10f10e279c628d5e7a5e", null ],
    [ "HandleCtrlChanged", "d0/dd0/gfx__func_8h.html#a183b9017f2eb1d4eadb870ff24acef78", null ],
    [ "HandleKeypress", "d0/dd0/gfx__func_8h.html#aeb918fa38fdc3fc0e1dd908992436489", null ],
    [ "HandleMouseEvents", "d0/dd0/gfx__func_8h.html#a7ef298a846836292da3cbb6b9fdb2d61", null ],
    [ "HandleTextInput", "d0/dd0/gfx__func_8h.html#a62a41d8ff12bb37d48b1c76264df4270", null ],
    [ "LoadStringWidthTable", "d0/dd0/gfx__func_8h.html#aac5a99c95e4913f9b4ab80c85dd423ee", null ],
    [ "MarkWholeScreenDirty", "d5/d48/group__dirty.html#ga94c77ddf45ec98384625cba512034f24", null ],
    [ "RedrawScreenRect", "d0/dd0/gfx__func_8h.html#aa02472750c233df959585e724fba4f3b", null ],
    [ "ScreenSizeChanged", "d0/dd0/gfx__func_8h.html#ac686351aa68925988c7537e19ec2cfef", null ],
    [ "SetAnimatedMouseCursor", "d0/dd0/gfx__func_8h.html#ab60eb5eb0a0ae49d3fb1a868faf85d34", null ],
    [ "SetDirtyBlocks", "d0/dd0/gfx__func_8h.html#afd8f980a4f4bc6ff0331e5d5b1c72bd3", null ],
    [ "SetMouseCursor", "d0/dd0/gfx__func_8h.html#a51992beff537758411d10897d822d330", null ],
    [ "SetMouseCursorBusy", "d0/dd0/gfx__func_8h.html#a607951b4f6911cdaa8d38b14d4c07c78", null ],
    [ "SortResolutions", "d0/dd0/gfx__func_8h.html#ab09a58c48b60658e5c7e638826ccc0d5", null ],
    [ "ToggleFullScreen", "d0/dd0/gfx__func_8h.html#a6c3d71aef57b8889c19026e91f0d4e2d", null ],
    [ "UndrawMouseCursor", "d0/dd0/gfx__func_8h.html#a0d13104b28e8889179ecb96896f6e1a5", null ],
    [ "UpdateCursorSize", "d0/dd0/gfx__func_8h.html#a0ba5acdd2730490e8ea3f8485854dfe9", null ],
    [ "UpdateWindows", "d0/dd0/gfx__func_8h.html#a252d24561ae37110b22fc42369e5da59", null ],
    [ "_colour_gradient", "d0/dd0/gfx__func_8h.html#a04e67e52c36bcf9ad6d879494e6b3e2e", null ],
    [ "_ctrl_pressed", "d0/dd0/gfx__func_8h.html#a449ad8ebe1b8f9b4eda3293236fba396", null ],
    [ "_cur_dpi", "d0/dd0/gfx__func_8h.html#a29b83a34f3f8b1f99d094cd8f4a9dc30", null ],
    [ "_cur_palette", "d0/dd0/gfx__func_8h.html#a82b91ff60054612cf4344e43ae7923e2", null ],
    [ "_cur_resolution", "d0/dd0/gfx__func_8h.html#ac48729b9ea3896e83dbaef1d930a01ae", null ],
    [ "_cursor", "d0/dd0/gfx__func_8h.html#a7b055b3dc8a5c15896a6ac0f0f6499c2", null ],
    [ "_dirkeys", "d0/dd0/gfx__func_8h.html#a52f15585b6bfb0944c9e6d2610069623", null ],
    [ "_fast_forward", "d0/dd0/gfx__func_8h.html#af6d3cc28b3e6a11938d0c828b6c3bb64", null ],
    [ "_fullscreen", "d0/dd0/gfx__func_8h.html#af41afe2d8abf7062f7aae1ae5e4dca26", null ],
    [ "_left_button_clicked", "d0/dd0/gfx__func_8h.html#a4f91b925a590a5658a6175d77b31c4fd", null ],
    [ "_left_button_down", "d0/dd0/gfx__func_8h.html#a29528c503a35cad849e24c62ccf54a2f", null ],
    [ "_num_resolutions", "d0/dd0/gfx__func_8h.html#a07d101a6ea51052a8785f174b11e21c1", null ],
    [ "_palette_remap_grf", "d0/dd0/gfx__func_8h.html#ad979bbe513effa2dbfd6e78acb2d6a5d", null ],
    [ "_resolutions", "d0/dd0/gfx__func_8h.html#a6eb2280641ec7c702afaf61415591c2c", null ],
    [ "_right_button_clicked", "d0/dd0/gfx__func_8h.html#a85547be96d2332331ca3386e66047398", null ],
    [ "_right_button_down", "d0/dd0/gfx__func_8h.html#aebb077b0ea0663869f537b974ef3c858", null ],
    [ "_screen", "d0/dd0/gfx__func_8h.html#aee3b2caf656df1c9e875f33841c8cf7f", null ],
    [ "_screen_disable_anim", "d0/dd0/gfx__func_8h.html#a4c49532bf3116616eab958b49c7cbbc0", null ],
    [ "_shift_pressed", "d0/dd0/gfx__func_8h.html#a15077a1979b5abe1e4cf850f392d37cb", null ],
    [ "_support8bpp", "d0/dd0/gfx__func_8h.html#a45bc881191b074f1a65f29bfc14de611", null ],
    [ "DRAW_STRING_BUFFER", "d0/dd0/gfx__func_8h.html#a7c60c2eedb8e2eb1e2fdb622b3f9bed8", null ],
    [ "PC_BLACK", "d0/dd0/gfx__func_8h.html#a5f5eba54b552cbbbff5f8538578efa5a", null ],
    [ "PC_DARK_BLUE", "d0/dd0/gfx__func_8h.html#a286c3607edeb321a2fce902e67ea18c7", null ],
    [ "PC_DARK_GREY", "d0/dd0/gfx__func_8h.html#a9691e4d60580a3dbbc3dcc76ce8e10d9", null ],
    [ "PC_DARK_RED", "d0/dd0/gfx__func_8h.html#aa28ec20c8d03a1a3de68dacff952a04b", null ],
    [ "PC_GREEN", "d0/dd0/gfx__func_8h.html#a60e6c4fa1ad67614084539d02ec5dcc6", null ],
    [ "PC_GREY", "d0/dd0/gfx__func_8h.html#aa4d5596816e815f2f8ba7e364e265a6f", null ],
    [ "PC_LIGHT_BLUE", "d0/dd0/gfx__func_8h.html#a2c65f0bfe61431e4ba323a81b40eb283", null ],
    [ "PC_LIGHT_YELLOW", "d0/dd0/gfx__func_8h.html#a56999fea39c8810c18918441c00ce3b8", null ],
    [ "PC_ORANGE", "d0/dd0/gfx__func_8h.html#a542d6b75702b5f8d351eccb07684a871", null ],
    [ "PC_RED", "d0/dd0/gfx__func_8h.html#a5c38cab18405557be76a29197c6f4fec", null ],
    [ "PC_VERY_DARK_BROWN", "d0/dd0/gfx__func_8h.html#a3d6cdee65a4ac0f9b33c44df5501ace1", null ],
    [ "PC_VERY_DARK_RED", "d0/dd0/gfx__func_8h.html#a371d3a39000b0e225b56e508d7a6ca54", null ],
    [ "PC_VERY_LIGHT_YELLOW", "d0/dd0/gfx__func_8h.html#a2d4608453685894dbfd9d8d8ed605954", null ],
    [ "PC_WHITE", "d0/dd0/gfx__func_8h.html#ae664e77cb3d1a7d3ce65751e2ad5ac4b", null ],
    [ "PC_YELLOW", "d0/dd0/gfx__func_8h.html#af0fb9fe76bdd818d5d3535648985228e", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d0/dd0/gfx__func_8h.js <==
var gfx__func_8h =
[
    [ "FONT_HEIGHT_LARGE", "d0/dd0/gfx__func_8h.html#a62522eeeaeb5b50af998dd8a13c447ad", null ],
    [ "FONT_HEIGHT_MONO", "d0/dd0/gfx__func_8h.html#a20b4e79411746dbd31e86ebbfd85e165", null ],
    [ "FONT_HEIGHT_NORMAL", "d0/dd0/gfx__func_8h.html#aff2dc4db5e63c9597125d923bedf2d6d", null ],
    [ "FONT_HEIGHT_SMALL", "d0/dd0/gfx__func_8h.html#a5c56df453a90cf0ee7b3aea41066df3d", null ],
    [ "GREY_SCALE", "d0/dd0/gfx__func_8h.html#afaa28737e6c4dd61079432236d6adaac", null ],
    [ "StringAlignment", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99", [
      [ "SA_LEFT", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a3299fdf5121ed16058ef242d7099f3cc", null ],
      [ "SA_HOR_CENTER", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a48262457106fe5a646c69912d722b465", null ],
      [ "SA_RIGHT", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a420b1bf5f176ea6c3ba6e6e21b334952", null ],
      [ "SA_HOR_MASK", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a38d19f9fd4e7355cc792ac751b2d056e", null ],
      [ "SA_TOP", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a2f65bd3a8e603db1d1ae97860e33919a", null ],
      [ "SA_VERT_CENTER", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99ac2ee4321f6ad27b143c45c3e08968102", null ],
      [ "SA_BOTTOM", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a6aa2b6fbb48e4473e800e7335527690f", null ],
      [ "SA_VERT_MASK", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a5bc08c8f21ed0859789898bdd626f774", null ],
      [ "SA_CENTER", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a860dce55fa7e76a776416e5b76fb2da2", null ],
      [ "SA_FORCE", "d0/dd0/gfx__func_8h.html#a2eac64bf72b115214ae431d3b9f9de99a5f69c54d9f8d7622a343b4613a90497c", null ]
    ] ],
    [ "AddDirtyBlock", "d5/d48/group__dirty.html#ga7e4302308faee4876d5d826b2e9714a0", null ],
    [ "CenterBounds", "d0/dd0/gfx__func_8h.html#a4b9b860f8f2f8bb3e04243eedc07aa74", null ],
    [ "ChangeResInGame", "d0/dd0/gfx__func_8h.html#ad1eb7560f1d63180c05e3e3bf9e2c9d7", null ],
    [ "CheckBlitter", "d0/dd0/gfx__func_8h.html#a765d119fce0424280141f196d128a1be", null ],
    [ "CreateConsole", "d0/dd0/gfx__func_8h.html#a9c93eb8d3d9e95f670a42345713af01a", null ],
    [ "CursorTick", "d0/dd0/gfx__func_8h.html#a21b47af832d17183a571d33709eb4ca4", null ],
    [ "DrawBox", "d0/dd0/gfx__func_8h.html#adcea9bd22fff70a074b68f66ef028aff", null ],
    [ "DrawCharCentered", "d0/dd0/gfx__func_8h.html#a53ad0b488a77ab282c23502757739cef", null ],
    [ "DrawDirtyBlocks", "d5/d48/group__dirty.html#ga82dbdab183007a06f3319f7e7e44d132", null ],
    [ "DrawMouseCursor", "d0/dd0/gfx__func_8h.html#a7474f42828d5ea48e4a7793cc1d63823", null ],
    [ "DrawOverlappedWindowForAll", "d0/dd0/gfx__func_8h.html#a3017c7de18d32f3149e840c144b6aeef", null ],
    [ "DrawSprite", "d0/dd0/gfx__func_8h.html#a48b053ea7505c95b2dcd99b6e13df774", null ],
    [ "DrawSpriteViewport", "d0/dd0/gfx__func_8h.html#a84d273ef7bdb70772085c116e01f4bcb", null ],
    [ "DrawString", "d0/dd0/gfx__func_8h.html#ac190834d6a4461d59a9d215015a5aa18", null ],
    [ "DrawString", "d0/dd0/gfx__func_8h.html#ab9c4cb4c78da47ab7772ace22be8a528", null ],
    [ "DrawStringMultiLine", "d0/dd0/gfx__func_8h.html#a91ad98f20f66633184f425ac064eba90", null ],
    [ "DrawStringMultiLine", "d0/dd0/gfx__func_8h.html#ac051d286b4e5c9ee3b60daeb8d583394", null ],
    [ "FillDrawPixelInfo", "d0/dd0/gfx__func_8h.html#aea9706a3f0deee7c415df4bcd4bbd243", null ],
    [ "GameLoop", "d0/dd0/gfx__func_8h.html#a1ccba604c34743e18775c4c72ff36948", null ],
    [ "GameSizeChanged", "d0/dd0/gfx__func_8h.html#a4560d58565a10931cc872203e4507e0c", null ],
    [ "GetBroadestDigit", "d0/dd0/gfx__func_8h.html#a7f2db578b3c0d8c001492d28e004ab99", null ],
    [ "GetCharacterHeight", "d0/dd0/gfx__func_8h.html#abdc18f304b99c345a3fb9774371ec96b", null ],
    [ "GetCharacterWidth", "d0/dd0/gfx__func_8h.html#ab7446c312745b77ad3bf4073d7135c43", null ],
    [ "GetCharAtPosition", "d0/dd0/gfx__func_8h.html#a89ae5a88a0c9bf3a615a74aada8aa0ec", null ],
    [ "GetCharPosInString", "d0/dd0/gfx__func_8h.html#a3b0d4ca81479d54226a5c8c3760ba915", null ],
    [ "GetContrastColour", "d0/dd0/gfx__func_8h.html#a94bbc005155c19357e771c20b30303f6", null ],
    [ "GetDigitWidth", "d0/dd0/gfx__func_8h.html#abe6fcc04b86b6238f1f10250d863d92c", null ],
    [ "GetSpriteSize", "d0/dd0/gfx__func_8h.html#aa1deaa3dbb2d9f269152b7a482016852", null ],
    [ "GetStringBoundingBox", "d0/dd0/gfx__func_8h.html#a4115002109446ab9b55f902dce0e50ff", null ],
    [ "GetStringBoundingBox", "d0/dd0/gfx__func_8h.html#a7bc77418c11174e17dceaa9c279d3423", null ],
    [ "GetStringHeight", "d0/dd0/gfx__func_8h.html#ae818cb9dcd589e3430675b5a64ae035f", null ],
    [ "GetStringHeight", "d0/dd0/gfx__func_8h.html#ac7aaeb816ab4f8f3cdf11e55d7603cc2", null ],
    [ "GetStringLineCount", "d0/dd0/gfx__func_8h.html#a39ed16837962bcfdef87e98f97df84b9", null ],
    [ "GetStringMultiLineBoundingBox", "d0/dd0/gfx__func_8h.html#a07bf77588ca7fafb6339af33098483d0", null ],
    [ "GetStringMultiLineBoundingBox", "d0/dd0/gfx__func_8h.html#ab8a303b48a03621231a4682580bbf6f8", null ],
    [ "GfxDrawLine", "d0/dd0/gfx__func_8h.html#a52fc1ddbafcb899fdabae7563daa95f6", null ],
    [ "GfxFillPolygon", "d0/dd0/gfx__func_8h.html#a1a30087cb468fd073d2b7e2878b1aaff", null ],
    [ "GfxFillRect", "d0/dd0/gfx__func_8h.html#ad176599a86e2c97daec082e2566223c2", null ],
    [ "GfxInitPalettes", "d0/dd0/gfx__func_8h.html#a447580145f88c4c8a962cc7299eb542d", null ],
    [ "GfxScroll", "d0/dd0/gfx__func_8h.html#a580ce1d1be3c10f10e279c628d5e7a5e", null ],
    [ "HandleCtrlChanged", "d0/dd0/gfx__func_8h.html#a183b9017f2eb1d4eadb870ff24acef78", null ],
    [ "HandleKeypress", "d0/dd0/gfx__func_8h.html#aeb918fa38fdc3fc0e1dd908992436489", null ],
    [ "HandleMouseEvents", "d0/dd0/gfx__func_8h.html#a7ef298a846836292da3cbb6b9fdb2d61", null ],
    [ "HandleTextInput", "d0/dd0/gfx__func_8h.html#a9ef3da5354f257deee0827f602115231", null ],
    [ "LoadStringWidthTable", "d0/dd0/gfx__func_8h.html#aac5a99c95e4913f9b4ab80c85dd423ee", null ],
    [ "MarkWholeScreenDirty", "d5/d48/group__dirty.html#ga94c77ddf45ec98384625cba512034f24", null ],
    [ "RedrawScreenRect", "d5/d48/group__dirty.html#gaa02472750c233df959585e724fba4f3b", null ],
    [ "ScreenSizeChanged", "d0/dd0/gfx__func_8h.html#ac686351aa68925988c7537e19ec2cfef", null ],
    [ "SetAnimatedMouseCursor", "d0/dd0/gfx__func_8h.html#ab60eb5eb0a0ae49d3fb1a868faf85d34", null ],
    [ "SetMouseCursor", "d0/dd0/gfx__func_8h.html#a51992beff537758411d10897d822d330", null ],
    [ "SetMouseCursorBusy", "d0/dd0/gfx__func_8h.html#a607951b4f6911cdaa8d38b14d4c07c78", null ],
    [ "SortResolutions", "d0/dd0/gfx__func_8h.html#acf6b1205cbb04e2959540ee14520d8d2", null ],
    [ "ToggleFullScreen", "d0/dd0/gfx__func_8h.html#a6c3d71aef57b8889c19026e91f0d4e2d", null ],
    [ "UndrawMouseCursor", "d0/dd0/gfx__func_8h.html#a0d13104b28e8889179ecb96896f6e1a5", null ],
    [ "UpdateCursorSize", "d0/dd0/gfx__func_8h.html#a0ba5acdd2730490e8ea3f8485854dfe9", null ],
    [ "UpdateWindows", "d0/dd0/gfx__func_8h.html#a252d24561ae37110b22fc42369e5da59", null ],
    [ "_colour_gradient", "d0/dd0/gfx__func_8h.html#a04e67e52c36bcf9ad6d879494e6b3e2e", null ],
    [ "_ctrl_pressed", "d0/dd0/gfx__func_8h.html#a449ad8ebe1b8f9b4eda3293236fba396", null ],
    [ "_cur_dpi", "d0/dd0/gfx__func_8h.html#a29b83a34f3f8b1f99d094cd8f4a9dc30", null ],
    [ "_cur_palette", "d0/dd0/gfx__func_8h.html#a82b91ff60054612cf4344e43ae7923e2", null ],
    [ "_cur_resolution", "d0/dd0/gfx__func_8h.html#ac48729b9ea3896e83dbaef1d930a01ae", null ],
    [ "_cursor", "d0/dd0/gfx__func_8h.html#a7b055b3dc8a5c15896a6ac0f0f6499c2", null ],
    [ "_dirkeys", "d0/dd0/gfx__func_8h.html#a52f15585b6bfb0944c9e6d2610069623", null ],
    [ "_fast_forward", "d0/dd0/gfx__func_8h.html#af6d3cc28b3e6a11938d0c828b6c3bb64", null ],
    [ "_fullscreen", "d0/dd0/gfx__func_8h.html#af41afe2d8abf7062f7aae1ae5e4dca26", null ],
    [ "_left_button_clicked", "d0/dd0/gfx__func_8h.html#a4f91b925a590a5658a6175d77b31c4fd", null ],
    [ "_left_button_down", "d0/dd0/gfx__func_8h.html#a29528c503a35cad849e24c62ccf54a2f", null ],
    [ "_palette_remap_grf", "d0/dd0/gfx__func_8h.html#ad979bbe513effa2dbfd6e78acb2d6a5d", null ],
    [ "_resolutions", "d0/dd0/gfx__func_8h.html#abd7b8dc12a1488a40efb11841ba440ec", null ],
    [ "_right_button_clicked", "d0/dd0/gfx__func_8h.html#a85547be96d2332331ca3386e66047398", null ],
    [ "_right_button_down", "d0/dd0/gfx__func_8h.html#aebb077b0ea0663869f537b974ef3c858", null ],
    [ "_screen", "d0/dd0/gfx__func_8h.html#aee3b2caf656df1c9e875f33841c8cf7f", null ],
    [ "_screen_disable_anim", "d0/dd0/gfx__func_8h.html#a4c49532bf3116616eab958b49c7cbbc0", null ],
    [ "_shift_pressed", "d0/dd0/gfx__func_8h.html#a15077a1979b5abe1e4cf850f392d37cb", null ],
    [ "_support8bpp", "d0/dd0/gfx__func_8h.html#a45bc881191b074f1a65f29bfc14de611", null ],
    [ "DRAW_STRING_BUFFER", "d0/dd0/gfx__func_8h.html#a7c60c2eedb8e2eb1e2fdb622b3f9bed8", null ],
    [ "PC_BARE_LAND", "d0/dd0/gfx__func_8h.html#a18900be4fd3b30ec3e1c1e4bace10b09", null ],
    [ "PC_BLACK", "d0/dd0/gfx__func_8h.html#a5f5eba54b552cbbbff5f8538578efa5a", null ],
    [ "PC_DARK_BLUE", "d0/dd0/gfx__func_8h.html#a286c3607edeb321a2fce902e67ea18c7", null ],
    [ "PC_DARK_GREY", "d0/dd0/gfx__func_8h.html#a9691e4d60580a3dbbc3dcc76ce8e10d9", null ],
    [ "PC_DARK_RED", "d0/dd0/gfx__func_8h.html#aa28ec20c8d03a1a3de68dacff952a04b", null ],
    [ "PC_FIELDS", "d0/dd0/gfx__func_8h.html#aedc57ea34064bb8159c157bf16050086", null ],
    [ "PC_GRASS_LAND", "d0/dd0/gfx__func_8h.html#a0343af16151dd391a0d18c21287cd009", null ],
    [ "PC_GREEN", "d0/dd0/gfx__func_8h.html#a60e6c4fa1ad67614084539d02ec5dcc6", null ],
    [ "PC_GREY", "d0/dd0/gfx__func_8h.html#aa4d5596816e815f2f8ba7e364e265a6f", null ],
    [ "PC_LIGHT_BLUE", "d0/dd0/gfx__func_8h.html#a2c65f0bfe61431e4ba323a81b40eb283", null ],
    [ "PC_LIGHT_YELLOW", "d0/dd0/gfx__func_8h.html#a56999fea39c8810c18918441c00ce3b8", null ],
    [ "PC_ORANGE", "d0/dd0/gfx__func_8h.html#a542d6b75702b5f8d351eccb07684a871", null ],
    [ "PC_RAINFOREST", "d0/dd0/gfx__func_8h.html#ae7eb4283d8dccca35b457dd5a3b815b0", null ],
    [ "PC_RED", "d0/dd0/gfx__func_8h.html#a5c38cab18405557be76a29197c6f4fec", null ],
    [ "PC_ROUGH_LAND", "d0/dd0/gfx__func_8h.html#ac1963dbf1e0bd55f2d34d123b7193a01", null ],
    [ "PC_TREES", "d0/dd0/gfx__func_8h.html#af5523ed070e2c1be00a6acc30275928c", null ],
    [ "PC_VERY_DARK_BLUE", "d0/dd0/gfx__func_8h.html#a988523ad8ae3b42b3c3297e70c5ce16b", null ],
    [ "PC_VERY_DARK_BROWN", "d0/dd0/gfx__func_8h.html#a3d6cdee65a4ac0f9b33c44df5501ace1", null ],
    [ "PC_VERY_DARK_RED", "d0/dd0/gfx__func_8h.html#a371d3a39000b0e225b56e508d7a6ca54", null ],
    [ "PC_VERY_LIGHT_YELLOW", "d0/dd0/gfx__func_8h.html#a2d4608453685894dbfd9d8d8ed605954", null ],
    [ "PC_WATER", "d0/dd0/gfx__func_8h.html#ab2966af4441ae7146eb234493669c56c", null ],
    [ "PC_WHITE", "d0/dd0/gfx__func_8h.html#ae664e77cb3d1a7d3ce65751e2ad5ac4b", null ],
    [ "PC_YELLOW", "d0/dd0/gfx__func_8h.html#af0fb9fe76bdd818d5d3535648985228e", null ]
];
